@@ -1,7 +1,7 @@
 #  -*- coding: utf-8 -*-
 # @author: zhangping
 
-import json
+import os, json, logbook, logbook.more
 import datetime as dt
 from urllib import request
 from urllib import parse
@@ -160,3 +160,25 @@ class IndexUtil:
             if last_date_result is not None and len(last_date_result) == 1:
                 last_date = last_date_result[0]
         return last_date
+
+
+class LoggerUtil:
+    @staticmethod
+    def get_logger(name='dqapi', level='INFO', std_log=True, file_log=True, logs_dir='./logs'):
+        if not os.path.exists(logs_dir): os.makedirs(logs_dir)
+        logbook.set_datetime_format('local')
+        log = logbook.Logger(name)
+        log.handlers = []
+        log_formate = lambda record, handler: \
+            f'[{record.time}] [{record.level_name}] [{os.path.split(record.filename)[-1]}] [{record.func_name}] [{record.lineno}] {record.message}'
+        if std_log:  # 屏幕打印
+            std_handler = logbook.more.ColorizedStderrHandler(level=level, bubble=True)
+            std_handler.formatter = log_formate
+            log.handlers.append(std_handler)
+        if file_log:  # 日志文件
+            file_handler = logbook.TimedRotatingFileHandler(
+                os.path.join(logs_dir, '%s.log' % 'log'), level=level, date_format='%Y-%m-%d', bubble=True,
+                encoding='utf-8')
+            file_handler.formatter = log_formate
+            log.handlers.append(file_handler)
+        return log
